@@ -18,11 +18,11 @@ class Equilibrium:
     
     Parameters
     ----------
-    imol=None : MaterialIndexer, optional
+    imol=None : :class:`~thermosteam.indexer.MaterialIndexer`, optional
         Molar chemical phase data is stored here.
-    thermal_condition=None : ThermalCondition, optional
+    thermal_condition=None : :class:`~thermosteam.ThermalCondition`, optional
         The temperature and pressure used in calculations are stored here.
-    thermo=None : Thermo, optional
+    thermo=None : :class:`~thermosteam.Thermo`, optional
         Themodynamic property package for equilibrium calculations.
         Defaults to `thermosteam.settings.get_thermo()`.
 
@@ -34,13 +34,20 @@ class Equilibrium:
     """
     __slots__ = ('_imol', '_thermal_condition', '_thermo')
     
-    def __init_subclass__(cls, phases):
+    def __init_subclass__(cls, phases=None):
         try: 
             cls.__call__
         except:
             raise NotImplementedError("Equilibrium subclasses must implement a "
-                                      "'__call__' method.")
-        cls._phases = phases
+                                      "'__call__' method")
+        if phases:
+            cls._phases = phases
+        else:
+            try:
+                cls._phases
+            except:
+                raise NotImplementedError("Equilibrium subclasses must implement a "
+                                          "'_phases' attribute")
     
     def __init__(self, imol=None, thermal_condition=None, thermo=None):
         self._load_thermo(thermo)
