@@ -57,7 +57,9 @@ class Mixture:
     
     Notes
     -----
-    Although the mixture models are on a molar basis, this is only if the molar data is normalized before the calculation (i. e. the `mol` parameter is normalized before being passed to the model).
+    Although the mixture models are on a molar basis, this is only if the molar
+    data is normalized before the calculation (i.e. the `mol` parameter is 
+    normalized before being passed to the model).
     
     See also
     --------
@@ -130,13 +132,13 @@ class Mixture:
     def solve_T(self, phase, mol, H, T_guess, P):
         """Solve for temperature in Kelvin."""
         args = (H, self.H, phase, mol, P, self.Cn(phase, mol, T_guess))
-        return flx.aitken(iter_temperature, T_guess, 1e-6, args, 10, checkiter=False)
-                
+        return flx.aitken(iter_temperature, T_guess, 1e-6, args, 50, checkiter=True)
+        
     def xsolve_T(self, phase_mol, H, T_guess, P):
         """Solve for temperature in Kelvin."""
         args = (H, self.xH, tuple(phase_mol), P, self.xCn(phase_mol, T_guess))
-        return flx.aitken(xiter_temperature, T_guess, 1e-6, args, 10, checkiter=False)
-    
+        return flx.aitken(xiter_temperature, T_guess, 1e-6, args, 50, checkiter=True)
+        
     def xCn(self, phase_mol, T):
         """Multi-phase mixture heat capacity [J/mol/K]."""
         Cn = self.Cn
